# BillingSubscriptionNewSubscription

Object for creating a new upstream subscription

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**description** | **str** | subscription description | [optional] 
**trial_period** | **int, none_type** | Product trial period (days)  | [optional] 
**currency** | **str** | The currency to use for the subscription | [optional] 
**updated_subscription** | [**BillingOrgSubscription**](BillingOrgSubscription.md) |  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


